@@ -2,20 +2,23 @@
 
 # python-gphoto2 - Python interface to libgphoto2
 # http://github.com/jim-easterbrook/python-gphoto2
-# Copyright (C) 2015-18  Jim Easterbrook  jim@jim-easterbrook.me.uk
+# Copyright (C) 2015-22  Jim Easterbrook  jim@jim-easterbrook.me.uk
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This file is part of python-gphoto2.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# python-gphoto2 is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# python-gphoto2 is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public
+# License along with python-gphoto2.  If not, see
+# <https://www.gnu.org/licenses/>.
 
 """Simple focusing aid - grabs preview images and displays them at full
 resolution.
@@ -34,9 +37,8 @@ The histogram and clipping count are useful when setting exposure.
 
 """
 
-from __future__ import print_function
-
 import io
+import locale
 import logging
 import math
 import sys
@@ -184,6 +186,7 @@ class CameraHandler(QtCore.QObject):
                     self.camera.set_config(self.config)
                     break
         # find the image format config item
+        # camera dependent - 'imageformat' is 'imagequality' on some
         OK, image_format = gp.gp_widget_get_child_by_name(
             self.config, 'imageformat')
         if OK >= gp.GP_OK:
@@ -364,9 +367,10 @@ class MainWindow(QtWidgets.QMainWindow):
 
 
 if __name__ == "__main__":
+    locale.setlocale(locale.LC_ALL, '')
     logging.basicConfig(
         format='%(levelname)s: %(name)s: %(message)s', level=logging.WARNING)
-    gp.check_result(gp.use_python_logging())
+    callback_obj = gp.check_result(gp.use_python_logging())
     app = QtWidgets.QApplication([])
     main = MainWindow()
     main.show()
